"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stagedConfig = exports.staged = exports.diffConfig = exports.diff = void 0;
const git_1 = require("./git");
const STAGED = true;
const isLineWithinRange = (line) => (range) => range.isWithinRange(line);
const diff = {
    preprocess: (text, filename) => git_1.getDiffFileList().includes(filename) ? [{ text, filename }] : [],
    postprocess: (messages, filename) => messages
        .map((message) => message.filter(({ line }) => git_1.getRangesForDiff(git_1.getDiffForFile(filename)).some(isLineWithinRange(line))))
        .reduce((a, b) => a.concat(b), []),
    supportsAutofix: true,
};
exports.diff = diff;
const diffConfig = {
    plugins: ["diff"],
    overrides: [
        {
            files: ["*"],
            processor: "diff/diff",
        },
    ],
};
exports.diffConfig = diffConfig;
const staged = {
    preprocess: (text, filename) => git_1.getDiffFileList(STAGED).includes(filename) ? [{ text, filename }] : [],
    postprocess: (messages, filename) => messages
        .map((message) => message.filter(({ line }) => git_1.getRangesForDiff(git_1.getDiffForFile(filename, STAGED)).some(isLineWithinRange(line))))
        .reduce((a, b) => a.concat(b), []),
    supportsAutofix: true,
};
exports.staged = staged;
const stagedConfig = {
    plugins: ["diff"],
    overrides: [
        {
            files: ["*"],
            processor: "diff/staged",
        },
    ],
};
exports.stagedConfig = stagedConfig;
